@@ -373,6 +373,14 @@ function mkvirtualenv {
     # the environment won't exist.  Use that to tell whether
     # we should switch to the environment and run the hook.
     [ ! -d "$WORKON_HOME/$envname" ] && return 0
+
+	# If they gave us a project directory, set it up now
+	# so the activate hooks can find it.
+    if [ ! -z "$project" ]
+    then
+        setvirtualenvproject "$WORKON_HOME/$envname" "$project"
+    fi
+
     # Now activate the new environment
     workon "$envname"
 
@@ -386,11 +394,6 @@ function mkvirtualenv {
         pip install $a
     done
 
-    if [ ! -z "$project" ]
-    then
-        setvirtualenvproject "" "$project"
-    fi
-
     virtualenvwrapper_run_hook "post_mkvirtualenv"
 }
 
@@ -668,7 +671,7 @@ function add2virtualenv {
             sed -i.tmp "\:^$absolute_path$: d" "$path_file"
         else
             sed -i.tmp '1 a\
-'$absolute_path'
+'"$absolute_path"'
 ' "$path_file"
         fi
         rm -f "${path_file}.tmp"
